function [pattern, dur] = patterns(partition);

% PATTERNS computes centers of gravity of recurrence domains
% function v = patterns(partition);
% mean patterns of recurrence domains
% input:
%
% partition :
% partition: structure array of fields
%
% outputs:
% pattern : array of recurrence domain patterns
% dur : array of relative pattern durations

% (C) Peter beim Graben, Humboldt-Universitt zu Berlin 2017
%
% References:
% beim Graben, P. & Hutt, A. (2013). Detecting recurrence domains of
% dynamical systems by symbolic dynamics.
% Physical Review Letters, 110, 154101.
% beim Graben, P. & Hutt, A. (2015). Detecting event-related recurrences 
% by symbolic analysis: Applications to human language processing.
% Philosophical Transactions of the Royal Society London, A373, 201400897.
% Hutt, A. & beim Graben, P. (2017). Sequences by metastable attractors: 
% interweaving dynamical systems and experimental data. 
% Frontiers in Applied Mathematics and Statistics, 3, 11.



% get number of recurrence domains
nd = size(partition, 2);

% total duration
total = 0;

% patterns, excluding "0"
for i = 1 : nd

    if partition(i).symbol        
        p = partition(i).symbol;        
        pattern(:, p) = mean(partition(i).domain, 2);
        dur(p) = size(partition(i).domain, 2);
        total = total + dur(p);                
    end
    
end

dur = dur / total;

return